#[repr(i32)]pub enum VariableEvaluationMode {
Unspecified = 0,
PerPlan = 1,
PerRecord = 2,
}Expand description
VariableEvaluationMode specifies the frequency and scope of execution context variable evaluation.
Variants
Unspecified = 0
PerPlan = 1
Variables are evaluated once per Substrait plan execution.
PerRecord = 2
Variables are evaluated once per record during execution.
Implementations
Sourceimpl VariableEvaluationMode
impl VariableEvaluationMode
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of VariableEvaluationMode.
Sourcepub fn from_i32(value: i32) -> Option<VariableEvaluationMode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<VariableEvaluationMode>
Use the TryFrom<i32> implementation instead
Converts an i32 to a VariableEvaluationMode, or None if value is not a valid variant.
Sourceimpl VariableEvaluationMode
impl VariableEvaluationMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<VariableEvaluationMode>
pub fn from_str_name(value: &str) -> Option<VariableEvaluationMode>
Creates an enum from field names used in the ProtoBuf definition.